@@ -54,6 +54,12 @@
 saveSimList <- function(sim, filename, fileBackend = 0, filebackedDir = NULL, envir, ...) {
   dots <- list(...)
 
+  quiet <- if (is.null(dots$quiet)) {
+    FALSE
+  } else {
+    if (isTRUE(dots$quiet)) TRUE else FALSE
+  }
+
   # clean up misnamed arguments
   if (!is.null(dots$fileBackedDir)) if (is.null(filebackedDir)) {
     filebackedDir <- dots$fileBackedDir
@@ -69,9 +75,9 @@ saveSimList <- function(sim, filename, fileBackend = 0, filebackedDir = NULL, en
     sim <- get(simName, envir = envir)
   }
   if (isTRUE(fileBackend[1] > 0)) {
-    mess <- capture.output(type = "message",
-                           sim <- do.call(Copy, append(list(sim, filebackedDir = filebackedDir), dots))
-    )
+    mess <- capture.output(type = "message", {
+      sim <- do.call(Copy, append(list(sim, filebackedDir = filebackedDir), dots))
+    })
     mess <- grep("Hardlinked version", mess, invert = TRUE)
     if (length(mess))
       lapply(mess, message)
@@ -83,6 +89,9 @@ saveSimList <- function(sim, filename, fileBackend = 0, filebackedDir = NULL, en
   if (!exists(".Random.seed", envir = .GlobalEnv, inherits = FALSE)) tmp <- runif(1)
   sim@.xData$._randomSeed <- get(".Random.seed", envir = .GlobalEnv, inherits = FALSE)
   sim@.xData$._rng.kind <- RNGkind()
+
+  if (isFALSE(quiet)) message("Saving simList object to file '", filename, "'.")
+
   if (exists("simName", inherits = FALSE)) {
     tmpEnv <- new.env(parent = emptyenv())
     assign(simName, sim, envir = tmpEnv)
@@ -92,6 +101,9 @@ saveSimList <- function(sim, filename, fileBackend = 0, filebackedDir = NULL, en
     #save(sim, file = filename)
     qs::qsave(sim, file = filename)
   }
+
+  if (isFALSE(quiet)) message("    ... saved!")
+
   return(invisible())
 }
 
@@ -238,6 +250,31 @@ zipSimList <- function(sim, zipfile, ..., outputs = TRUE, inputs = TRUE, cache =
 loadSimList <- function(filename, paths = getPaths(), otherFiles = "") {
   sim <- qs::qread(filename, nthreads = getOption("spades.nThreads", 1))
 
+  # Work around for bug in qs that recovers data.tables as lists
+  objectName <- ls(sim)
+  names(objectName) <- objectName
+  objectClassInSim <- lapply(objectName, function(x) is(get(x, envir = sim))[1])
+  dt <- data.table(objectName, objectClassInSim)
+
+  io <- inputObjects(sim)
+  oo <- outputObjects(sim)
+  if (is(io, "list")) io <- rbindlist(io, fill = TRUE)
+  if (is(oo, "list")) oo <- rbindlist(oo, fill = TRUE)
+  objs <- rbindlist(list(io, oo), fill = TRUE)
+  objs <- unique(objs, by = "objectName")[, c("objectName", "objectClass")]
+
+  objs <- objs[dt, on = "objectName"]
+  objs <- objs[objectClass == "data.table"]
+  objs <- objs[objectClass != objectClassInSim]
+  if (NROW(objs)) {
+    message("There is a bug in qs package that recovers data.table objects incorrectly when in a list")
+    message("Converting all known data.table objects (according to metadata) from list to data.table")
+    simEnv <- envir(sim)
+    out <- lapply(objs$objectName, function(on) {
+      assign(on, as.data.table(sim[[on]]), envir = simEnv)
+    })
+  }
+
   mods <- setdiff(sim@modules, .coreModules())
   ## TODO: this should be unnecessary after June 2020 R-devel fix for active bindings
   lapply(mods, function(mod) {
@@ -356,4 +393,3 @@ unzipSimList <- function(zipfile, load = TRUE, paths = getPaths(), ...) {
   }
   return(unzippedFiles)
 }
-
